@@ -1,8 +1,8 @@
 from tkinter.ttk import Frame
 
 class BaseTab(Frame):
-   def __init__(self, master):
-      super().__init__(master)
+   def __init__(self, master = None, **kw):
+      super().__init__(master, **kw)
       
       self._frame = Frame(self)
       self._frame.pack(expand = True)
@@ -23,13 +23,13 @@ class BaseTab(Frame):
          self._ui = CommonUIComponents.inflate(self._frame, self._config)
    
    @staticmethod
-   def load(notebook, wholeConfig, tabsDir):
+   def load(notebook, wholeConfig, tabsDir, **baseTabKw):
       from importlib import import_module
       
       for module, config in wholeConfig["tabs"].items():
          module = import_module(f"{tabsDir}.{module}")
          
-         tab = module.Tab(notebook)
+         tab = module.Tab(notebook, **baseTabKw)
          tab._inflate(config)
          
          notebook.add(tab, text = tab.caption)
